<?php
error_reporting(E_ALL & ~(E_DEPRECATED | E_STRICT | E_NOTICE));

/**
 * @KingSize since 2011 - 2016
 * Developed by OurWebMedia - https://www.ourwebmedia.com
 **/
 
 
#---------------------------------------------------------------#
###################### Get custom function ######################
#---------------------------------------------------------------#

include (get_template_directory() . "/lib/custom.lib.php");

#--------------------------------------------------------------------------#
###################### Setup Theme page custom fields ######################
#--------------------------------------------------------------------------#

include (get_template_directory() . "/lib/theme-page-custom-fields.php");

#--------------------------------------------------------------------------#
###################### Setup Theme post custom fields ######################
#--------------------------------------------------------------------------#

include (get_template_directory() . "/lib/theme-post-custom-fields.php");


#--------------------------------------------------------------------------#
###################### Setup Theme product custom fields ######################
#--------------------------------------------------------------------------#
if ( 
  in_array( 
    'woocommerce/woocommerce.php', 
    apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) 
  ) 
) {
    // Put your plugin code here
    include (get_template_directory() . "/lib/theme-product-custom-fields.php");

}

#--------------------------------------------------------------------------#
###################### Setup Theme download custom fields ######################
#--------------------------------------------------------------------------#
if ( 
  in_array( 
    'easy-digital-downloads/easy-digital-downloads.php', 
    apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) 
  ) 
) {
    // Put your plugin code here
    include (get_template_directory() . "/lib/theme-download-custom-fields.php");

}

#---------------------------------------------------------------#
######################  Widget for sidebar ######################
#---------------------------------------------------------------#

require_once (get_template_directory() . '/lib/widget-contact-info.php');
require_once (get_template_directory() . '/lib/widget-twitter.php');
require_once (get_template_directory() . '/lib/gallery-widget/gallery_widget.php');

#------------------------------------------------------------#
###################### Image Resizer V4 ######################
#------------------------------------------------------------#

require_once(get_template_directory() . '/lib/image-resizer.php');


#---------------------------------------------------------------#
###################### WordPress Functions ######################
#---------------------------------------------------------------#

/** Tell WordPress to run kingsize_setup() when the 'after_setup_theme' hook is run. **/
add_action( 'after_setup_theme', 'kingsize_setup' );

if ( ! function_exists( 'kingsize_setup' ) ):

 /**
 * Sets up theme defaults and registers support for various WordPress features.
 * @uses add_theme_support() To add support for post thumbnails and automatic feed links.
 * @uses register_nav_menus() To add support for navigation menus.
 * @uses add_custom_background() To add support for a custom background.
 * @uses add_editor_style() To style the visual editor.
 * @uses load_theme_textdomain() For translation/localization support.
 * @uses add_custom_image_header() To add support for a custom header.
 * @uses register_default_headers() To register the default custom header images provided with the theme.
 * @uses set_post_thumbnail_size() To set a custom post thumbnail size.
 **/
 
function kingsize_setup() {
	// This theme uses post thumbnails
	//Deprecated from WP 3.9 add_theme_support( 'post-thumbnails', array( 'post', 'slider', 'track' ) );
	
	if ( function_exists( 'add_theme_support' ) ) {
		add_theme_support( 'post-thumbnails' );
		set_post_thumbnail_size( 460, 180, true );
		add_image_size( 'thumbnail-post', 200, 150, true ); // Post portfolio thumbnails
	}	
	// Add default posts and comments RSS feed links to head
	add_theme_support( 'automatic-feed-links' );	
	
	
	 ################## Fixing Theme Check Errors #################
	// Set up the content width value based on the theme's design and stylesheet.
	if ( ! isset( $content_width ) )
		$content_width = 1000;

	//Theme to support Title Tag
	add_theme_support( 'title-tag' );
	

	$defaults_custom_headers = array();
	add_theme_support( 'custom-header', $defaults_custom_headers );

	$args_custom_background = array();
	add_theme_support( "custom-background", $args_custom_background );  

	// This theme styles the visual editor with editor-style.css to match the theme style.
	add_editor_style();
	################## End Theme Check #################


}
endif;



/**
 * 
 * This removes the ability to add the FULL image size into a post, it does not alter or delete the image
 * Add whataever extra image sizes to the insert dropdown in WordPress you create via add_image_size
 * 
 *  For now we have to do it this way to make the labels translatable, see trac ref below.
 *
 *  If your theme has $content_width GLOBAL make sure and remove it
*/
//example to add post-size instead of using $content_width and a max-size
add_image_size( 'post-size', 460, 9999, true);
add_image_size( 'max-size', 700, 9999, true);
 
// over-ride image_size_names_choose
function add_image_insert_override($size_names){
 
  global $_wp_additional_image_sizes;
 
       //default array with hardcoded values for add_image_size
        $size_names = array(
                          'thumbnail' => __('Thumbnail', 'kslang'), 
                          'medium'    => __('Medium', 'kslang'), 
                          'large'     => __('Large', 'kslang'),
                          'post-size' => __('Post Size', 'kslang'),
                          'max-size'  => __('Max Size', 'kslang'),
                          'full'      => __('Full Size', 'kslang') 
                        );
 
      return $size_names;
 
};
 
add_filter('image_size_names_choose', 'add_image_insert_override' );
 
#--------------------------------------------------------------------------#
######################  Change Default Excerpt Length ######################
#--------------------------------------------------------------------------#

function kingsize_excerpt_length($length) {
return 30; }
add_filter('excerpt_length', 'kingsize_excerpt_length');

#---------------------------------------------------------------------#
######################  Configure Excerpt String ######################
#---------------------------------------------------------------------#

function kingsize_excerpt_more($excerpt) {
return str_replace('[...]', '...', $excerpt); }
add_filter('wp_trim_excerpt', 'kingsize_excerpt_more');

#------------------------------------------------------------------------------------------#
###################### Get our wp_nav_menu() fallback, wp_page_menu() ######################
#------------------------------------------------------------------------------------------#

function kingsize_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'kingsize_page_menu_args' );

#---------------------------------------------------------------------------#
###################### Widget Ready / Enabled Sidebars ######################
#---------------------------------------------------------------------------#

function kingsize_widgets_init() {
	register_sidebar( array(
		'name' => 'Main Blog Sidebar',
		'id' => 'primary-widget-area',
		'description' => 'The main WordPress sidebar.',
		'before_widget' => '<div id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	
	register_sidebar( array(
		'name' => 'Pages Sidebar',
		'id' => 'pages-sidebar',
		'description' => 'Sidebar specific to Pages.',
		'before_widget' => '<div id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	
	register_sidebar( array(
		'name' => 'Contact Page Sidebar',
		'id' => 'contact-page-sidebar',
		'description' => 'Ideal for additional contact details, displayed as the Sidebar on the Contact Page. Can be used for anything.',
		'before_widget' => '<div id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	
	register_sidebar( array(
		'name' => 'WooCommerce Sidebar',
		'id' => 'woocommerce-widget-area',
		'description' => 'Sidebar specific to WooCommerce when installed and active.',
		'before_widget' => '<div id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	
	register_sidebar( array(
		'name' => 'Easy Digital Downloads Sidebar',
		'id' => 'easy-dd-widget-area',
		'description' => 'Sidebar specific to the Easy Digital Downloads plugin when installed.',
		'before_widget' => '<div id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	register_sidebar( array(
		'name' => 'Footer Column Left',
		'id' => 'first-footer-widget-area',
		'description' => 'The first footer widget area / column.',
		'before_widget' => '<div id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	register_sidebar( array(
		'name' => 'Footer Column Center',
		'id' => 'second-footer-widget-area',
		'description' => 'The second footer widget area / column.',
		'before_widget' => '<div id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	register_sidebar( array(
		'name' => 'Footer Column Right',
		'id' => 'third-footer-widget-area',
		'description' => 'The third footer widget area / column.',
		'before_widget' => '<div id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	
}

#--------------------------------------------------------------------#
###################### Register Widget Sidebars ######################
#--------------------------------------------------------------------#

add_action( 'widgets_init', 'kingsize_widgets_init' );

#------------------------------------------------------------------#
###################### Comment Style Settings ######################
#------------------------------------------------------------------#

function kingsize_remove_recent_comments_style() {
	global $wp_widget_factory;
	remove_action( 'wp_head', array( $wp_widget_factory->widgets['WP_Widget_Recent_Comments'], 'recent_comments_style' ) );
}
add_action( 'widgets_init', 'kingsize_remove_recent_comments_style' );

#-----------------------------------------------------------------#
###################### Theme Options Setting ######################
#-----------------------------------------------------------------#

global $data;
require_once ('admin/index.php');

#-----------------------------------------------------------------#
###################### Menu Navitation Setup ######################
#-----------------------------------------------------------------#

require_once ('lib/menu-walker.php');

add_action( 'init', 'register_my_menus' );
function register_my_menus() {
register_nav_menus(array(
'header-nav' => __( 'Header Navigation', 'kslang' )
));
}

#-----------------------------------------------------#
###################### Home Body ######################
#-----------------------------------------------------#

function my_plugin_body_class($classes) {
    $classes[] = 'body_portfolio body_colorbox body_gallery_2col_cb';
    return $classes;
}
add_filter('body_class', 'my_plugin_body_class');
 
#-------------------------------------------------------------#
###################### Admin E-MAIL HERE ######################
#-------------------------------------------------------------#

define("webmaster_email", $data['wm_contact_email']);
define("thanks_message", $data['wm_contact_email_template']);

#-----------------------------------------------------------------------#
######################  Enqueue Scripts and Styles ######################
#-----------------------------------------------------------------------#
function my_init_method() {
global $data;

    if (!is_admin()) {
        wp_dequeue_script( 'jquery' );
        wp_register_script( 'jquery', '//ajax.googleapis.com/ajax/libs/jquery/2.1.1/jquery.min.js');
        wp_enqueue_script( 'jquery' );
        
        //enque foundation framework script
		wp_register_script( 'foundation', get_template_directory_uri().'/js/foundation.min.js'); 
	
	    // register Google Fonts stylesheet
		if($data['wm_google_fonts']!='')
			wp_register_style( 'google-fonts', $data['wm_google_fonts']);
		else
			wp_register_style( 'google-fonts', '//fonts.googleapis.com/css?family=PT+Sans+Narrow|PT+Sans:i,b,bi');

		// enqueue Google Fonts stylesheet
		wp_enqueue_style( 'google-fonts');
		
		if($data["wm_lazyloader_option"] == "Enable Lazyloader") :
			wp_register_script('lazyload', get_template_directory_uri() . "/js/jquery.lazyload.min.js");
			wp_enqueue_script('lazyload');
		endif;
		
		// Load Retina js if retina image option enable.
        if ($data["wm_retina_image_option"] == "Enable Retina Image") :
            wp_register_script('retina_js', get_template_directory_uri() . "/js/retina.js");
            wp_enqueue_script('retina_js');
        endif;
		
		//recaptcha
		wp_register_script( 'recaptcha', '///www.google.com/recaptcha/api.js');
		if($data["wm_recaptcha_key"] != "" && $data["wm_recaptcha_secret"] != "") :
			wp_enqueue_script( 'recaptcha' );
        endif;
		
		wp_register_script('custom', get_template_directory_uri() . "/js/custom.js");
		wp_enqueue_script('custom');

        wp_register_script('tipsy', get_template_directory_uri() . "/js/jquery.tipsy.js");
		wp_enqueue_script('tipsy');   
		
		##### V4.0.2 update ########
		if($data["wm_prettyphoto_enabled"] == "0" || $data["wm_prettyphoto_enabled"] == "") :
			//registering prettyphoto style and script
			wp_register_style( 'prettyphoto-css', get_template_directory_uri().'/css/prettyPhoto.css');
			wp_register_script('prettyphoto-js', get_template_directory_uri() . "/js/jquery.prettyPhoto.js");
		endif;
		
		
		//isotopes
		wp_register_script( 'isotope', get_template_directory_uri() . "/js/isotope.pkgd.min.js");

    }
}    
 
add_action('init', 'my_init_method');

#-----------------------------------------------------------#
######################  Add shortcodes ######################
#-----------------------------------------------------------#

include (get_template_directory() . "/lib/shortcodes.php");

#----------------------------------------------------#
######################  TinyMCE ######################
#----------------------------------------------------#

require_once (get_template_directory() . '/lib/tinymce/tinymce.php');

#--------------------------------------------------------------------#
######################  Password protected page ######################
#--------------------------------------------------------------------#

function wm_the_password_form() {
    global $post;

    $label = 'pwbox-'.(empty($post->ID) ? rand() : $post->ID);
    $output = '<div class="password-protected"><form action="' . get_option('siteurl') . '/wp-login.php?action=postpass" method="post">
    <p><strong>' . __("This is a password protected page with private content.", "kslang") . '</strong></p>
    <p><div for="' . $label . '" style="padding-top:10px;">' . __("Enter your password below:", "kslang") . '</div><div style="padding-top:10px;"> <input name="post_password" id="' . $label . '" type="password" size="20" class="" /> <input type="submit" name="Submit" class="send-link" value="' . __("Login","kslang") . '" /></div></p>
    </form></div>';

    return $output;
}
add_filter('the_password_form', 'wm_the_password_form');

#-----------------------------------------------------------------#
######################  Get the Blog Content ######################
#-----------------------------------------------------------------#

function get_content($more_link_text = '(more...)', $stripteaser = 0, $more_file = '')
{
	$content = get_the_content($more_link_text, $stripteaser, $more_file);
	$content = apply_filters('the_content', $content);
	$content = str_replace(']]>', ']]&gt;', $content);
	return $content;
}

#------------------------------------------------------------------------------------------#
######################  List categories for the portfolio in frontend ######################
#------------------------------------------------------------------------------------------#

class Portfolio_Walker extends Walker_Category {
   function start_el(&$output, $category, $depth = 0, $args = array(), $id = 0) {
      extract($args);
      $cat_name = esc_attr( $category->name);
      $cat_name = apply_filters( 'list_cats', $cat_name, $category );
      $link = '<a href="#" data-value="'.strtolower(preg_replace('/\s+/', '-', $cat_name)).'" ';
      if ( $use_desc_for_title == 0 || empty($category->description) )
         $link .= 'title="' . sprintf(__( 'View all items filed under %s', 'kslang' ), $cat_name) . '"';
      else
         $link .= 'title="' . esc_attr( strip_tags( apply_filters( 'category_description', $category->description, $category ) ) ) . '"';
      $link .= '>';
      // $link .= $cat_name . '</a>';
      $link .= $cat_name;
      if(!empty($category->description)) {
         $link .= ' <span>'.$category->description.'</span>';
      }
      $link .= '</a>';
      if ( (! empty($feed_image)) || (! empty($feed)) ) {
         $link .= ' ';
         if ( empty($feed_image) )
            $link .= '(';
         $link .= '<a href="' . get_category_feed_link($category->term_id, $feed_type) . '"';
         if ( empty($feed) )
            $alt = ' alt="' . sprintf(__( 'Feed for all posts filed under %s', 'kslang' ), $cat_name ) . '"';
         else {
            $title = ' title="' . $feed . '"';
            $alt = ' alt="' . $feed . '"';
            $name = $feed;
            $link .= $title;
         }
         $link .= '>';
         if ( empty($feed_image) )
            $link .= $name;
         else
            $link .= "<img src='$feed_image'$alt$title" . ' />';
         $link .= '</a>';
         if ( empty($feed_image) )
            $link .= ')';
      }
      if ( isset($show_count) && $show_count )
         $link .= ' (' . intval($category->count) . ')';
      if ( isset($show_date) && $show_date ) {
         $link .= ' ' . gmdate('Y-m-d', $category->last_update_timestamp);
      }
      if ( isset($current_category) && $current_category )
         $_current_category = get_category( $current_category );
      if ( 'list' == $args['style'] ) {
          $output .= '<li class="segment-'.rand(2, 99).'"';
          $class = 'cat-item cat-item-'.$category->term_id;
          if ( isset($current_category) && $current_category && ($category->term_id == $current_category) )
             $class .=  ' current-cat';
          elseif ( isset($_current_category) && $_current_category && ($category->term_id == $_current_category->parent) )
             $class .=  ' current-cat-parent';
          $output .=  '';
          $output .= ">$link\n";
       } else {
          $output .= "\t$link<br />\n";
       }
   }
}

#---------------------------------------------------------------#
######################  Portfolio in Admin ######################
#---------------------------------------------------------------#

// create the portfolio Post types for admin
include(get_template_directory() ."/lib/portfolio/portfolio-posttype.php");

// Add the Portfolio Custom Meta
include(get_template_directory() ."/lib/portfolio/portfolio-meta.php");

// Add the portfolio Custom Fields
// 6/26/2013 commented in V 4.1 include(get_template_directory() ."/lib/portfolio/portfolio-custom-fields.php");

include(get_template_directory() ."/lib/portfolio/portfolio-functions.php");

///removing the custom field from the writeup panel
function remove_metaboxes() {
 remove_meta_box( 'postcustom' , 'portfolio' , 'normal' ); //removes custom fields for page
 remove_meta_box( 'postcustom' , 'post' , 'normal' ); //removes custom fields for page
 remove_meta_box( 'postcustom' , 'page' , 'normal' ); //removes custom fields for page
}
add_action( 'admin_menu' , 'remove_metaboxes' );

////Include Custom Post Types Portfolio in Search Results and Archives
function filter_search($query) {
	
	//Getting all post types registered
	$postTypeArr = array();
	$postTypeArr[] = 'page';
	$postTypeArr[] = 'post';
	$args = array(
		'public'   => true,
		'_builtin' => false
	);
	foreach ( get_post_types( $args, 'names' ) as $post_type ) {
		$postTypeArr[] = $post_type;
	}
	
    if ($query->is_search) {
	$query->set('post_type', $postTypeArr);
    };
    return $query;
    
};
if (!is_admin())	{
add_filter('pre_get_posts', 'filter_search');
}


//// add a default-gravatar to options ////
//// removed at Reviewers Request in v6.0 ////
//function newgravatar ($avatar_defaults) {
//    $myavatar = get_template_directory_uri() . '/images/comment_avatar.jpg';
//    $avatar_defaults[$myavatar] = "KingSize Gravatar";
//    return $avatar_defaults;
//}
//add_filter( 'avatar_defaults', 'newgravatar' );

//// translate reply for comments ////
function custom_comment_reply($content) {
	$content = str_replace('Reply', __('Reply', 'kslang'), $content);
	return $content;
}
add_filter('comment_reply_link', 'custom_comment_reply');

########### To identify the first and last menu item ##########
function mytheme_options() {
	global $wpdb;
	
	$topmenuid = get_theme_mod('nav_menu_locations');
	if ($topmenuid['header-nav'] != '0') {
		$menutermtax = $wpdb->get_var("SELECT term_taxonomy_id FROM $wpdb->term_taxonomy WHERE term_id = " . $topmenuid['header-nav']);
		
		$menuitem_post_ids = $wpdb->get_var("
		SELECT posts.ID
		FROM " . $wpdb->prefix . "posts AS posts
		INNER JOIN (
		SELECT object_id
		FROM " . $wpdb->prefix . "term_relationships
		WHERE term_taxonomy_id = " . $menutermtax . "
		) AS termid ON termid.object_id = posts.ID
		ORDER BY posts.menu_order DESC
		LIMIT 1
		");
		
		set_theme_mod('lastmenuitem',$menuitem_post_ids);
	}
}
// To fix the some server issues add_action('init', 'mytheme_options');

#----------------------------------------------------------------------#
###################### New Additions in Version 4 ######################
#----------------------------------------------------------------------#

// create the slider Post types for admin
include(get_template_directory() ."/lib/slider/slider-posttype.php");

// Add the slider Custom Meta
include(get_template_directory() ."/lib/slider/slider-meta.php");

// create the gallery Post types for admin
include(get_template_directory() ."/lib/gallery/gallery-posttype.php");

// Add the gallery Custom Meta
include(get_template_directory() ."/lib/gallery/gallery-meta.php");

// Add Gallery Shortcodes
include(get_template_directory() ."/lib/gallery/gallery_shortcodes.php");

// language files
load_theme_textdomain('kslang', get_template_directory() . '/lang');
$locale = get_locale();
$locale_file = get_template_directory()."/lang/$locale.php";
if(is_readable($locale_file)) require_once($locale_file);

//ON activation of theme update data of the theme
require_once get_template_directory()."/lib/theme_activation_hook.php";

//Simply shows the ID of Posts, Pages, Media, Links, Categories, Tags and Users in the admin tables for easy access.
include(get_template_directory() ."/lib/simply-show-ids.php");

#### Check this box if you want to hide/collapse the navigation by default. #####
if(!isset($data['wm_navigation_hide_enabled']))
	$data['wm_navigation_hide_enabled'] = "Show the Navigation on All Pages";

if($data['wm_navigation_hide_enabled'] == "Hide the Navigation on All Pages" || $data['wm_navigation_hide_enabled'] == "1")
{
	add_filter('body_class','kingsize_body_menu_hide');
}
elseif($data['wm_navigation_hide_enabled'] == "Hide the Navigation only on Homepage"){
  
   add_action('get_header', 'kingsize_get_method'); //Call the get header action hook to call is_home function etc
	function kingsize_get_method() {
	  if (is_page('home')) { //have also used is_page('home') to no avail
		 add_filter('body_class','kingsize_body_menu_hide');		  
	  }
	  elseif(is_home()){
		   add_filter('body_class','kingsize_body_menu_hide');		   
	   }
	}
}

// Slider controller positions
$slider_controller_position = '';

// getting the post ID
$url = explode('?', 'http://'.$_SERVER["HTTP_HOST"] . $_SERVER["REQUEST_URI"]);
$ID = url_to_postid($url[0]);


##### Exclude the_post_thumbnail from gallery shortcode ########
function exclude_thumbnail_from_gallery($null, $attr)
{
    if (!$thumbnail_ID = get_post_thumbnail_id())
        return $null; // no point carrying on if no thumbnail ID

    // temporarily remove the filter, otherwise endless loop!
    remove_filter('post_gallery', 'exclude_thumbnail_from_gallery');

    // pop in our excluded thumbnail
    if (!isset($attr['exclude']) || empty($attr['exclude']))
        $attr['exclude'] = array($thumbnail_ID);
    elseif (is_array($attr['exclude']))
        $attr['exclude'][] = $thumbnail_ID;

    // now manually invoke the shortcode handler
    $gallery = gallery_shortcode($attr);

    // add the filter back
    add_filter('post_gallery', 'exclude_thumbnail_from_gallery', 10, 2);

    // return output to the calling instance of gallery_shortcode()
    return $gallery;
}
add_filter('post_gallery', 'exclude_thumbnail_from_gallery', 10, 2);

// Removes WYSIWYG Editor from Gallery Post-type
function wpse_78595_hide_editor() {
    global $current_screen;

    if( $current_screen->post_type == 'galleries' ) {
        $css = '<style type="text/css">';
            $css .= '#wp-content-editor-container, #post-status-info, .wp-switch-editor, #postexcerpt { display: none; }';
        $css .= '</style>';

        echo $css;
    }
}
add_action('admin_footer', 'wpse_78595_hide_editor');

// Calls uploaded logo for WordPress Login Branding
function custom_login_logo() {
	global $data;

	if($data["wm_login_branding"] == 1)
	{
		$theme_custom_logo = $data['wm_logo_upload'];
		$login_background_color = $data['wm_login_background_color'];
		$login_label_color = $data['wm_login_label_color'];
		$login_link_color = $data['wm_login_link_color'];
		echo '<style type="text/css">'.
				 '.login h1 a { background-image:url('.$theme_custom_logo.') !important; width: 200px !important; height: 220px !important; background-size: auto !important; }'.
				'#login { padding: 3% 0 0 !important; }'.
				'body.login, html { background: '.$login_background_color.'  !important; }'.
				'.login label { color: '.$login_label_color.'  !important; }'.
				'.login #nav a, .login #backtoblog a { color: '.$login_link_color.'  !important; }'.
			 '</style>';
	}

}
add_action( 'login_head', 'custom_login_logo' );

// Changes WordPress Login Logo Link to use the WordPress Installation Link
function custom_login_url() {
    return home_url( '/' );
}
add_filter( 'login_headerurl', 'custom_login_url' );
 
// Changes the Alt tag to use the WordPress Installation Title
function custom_login_title() {
    return get_option( 'blogname' );
}
add_filter( 'login_headertitle', 'custom_login_title' );


#---------------------------------------------------------------#
############ Get Unlimited Sidebar function #####################
#---------------------------------------------------------------#
include (get_template_directory() . "/lib/sidebar-generator/sidebar_generator.php");



#---------------------------------------------------------------#
############ Plugin update notification #####################
#---------------------------------------------------------------#
if ( function_exists( 'vc_set_as_theme' ) ) {
	vc_set_as_theme( $notifier = true ); // Disable auto updates
}					

#---------------------------------------------------------------#
############ Plugin Activation  #####################
#---------------------------------------------------------------#
require_once( get_template_directory() . '/lib/plugins/class-tgm-plugin-activation.php' );

if ( ! function_exists( 'ks_register_required_plugins' ) ) {
	
	function ks_register_required_plugins() {

		$plugins = array(
		
			array(
				'name'               => 'Fullwidth Audio Player',
				'slug'               => 'fullwidth-audio-player',
				'source'             => get_template_directory() . '/lib/plugins/' . 'fullwidth-audio-player.zip',
				'required'           => false,
				'version'            => '2.0.1',
				'force_activation'   => false,
				'force_deactivation' => false,
			),

			array(
				'name'               => 'WPBakery Visual Composer',
				'slug'               => 'js_composer',
				'source'             => get_template_directory() . '/lib/plugins/' . 'js_composer.zip',
				'required'           => false,
				'version'            => '5.6',
				'force_activation'	 => false,
				'force_deactivation' => false,
			),
			
			array(
				'name'      => 'Contact Form 7',
				'slug'      => 'contact-form-7',
				'required' 	=> false,
			),
			
			array(
				'name'      => 'Yoast SEO',
				'slug'      => 'wordpress-seo',
				'required' 	=> false,
			),
			
			array(
				'name' => 'WooCommerce',
				'slug' => 'woocommerce',
				'required' 	=> false,
			),
				
		);

		$config = array(
			'default_path' => '',                      // Default absolute path to pre-packaged plugins.
			'menu'         => 'tgmpa-install-plugins', // Menu slug.
			'has_notices'  => true,                    // Show admin notices or not.
			'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
			'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
			'is_automatic' => true,                   // Automatically activate plugins after installation or not.
			'message'      => '',                      // Message to output right before the plugins table.
		);
 
		tgmpa( $plugins, $config );

	}
	
}
add_action( 'tgmpa_register', 'ks_register_required_plugins' );

/* Mobile detect */
require_once( get_template_directory() . '/lib/plugins/Mobile_Detect.php' );



/* Media Upload */
 add_action ( 'admin_enqueue_scripts', 'media_upload_to_new');
function media_upload_to_new(){
  if (is_admin ())
    wp_enqueue_media();
}

/* remove the H3 tag for the reply-title I.D */
function my_comment_form_before() {
    ob_start();
}
add_action( 'comment_form_before', 'my_comment_form_before' );

function my_comment_form_after() {
    $html = ob_get_clean();
    $html = preg_replace(
        '/<h3 id="reply-title"(.*)>(.*)<\/h3>/',
        '<h4 id="reply-title" class="comment-reply-title"\1>\2</h4>',
        $html
    );
    echo $html;
}
add_action( 'comment_form_after', 'my_comment_form_after' );

// Easy Digital Downloads Comments
function modify_edd_product_supports($supports) {
	$supports[] = 'comments';
	return $supports;	
}
add_filter('edd_download_supports', 'modify_edd_product_supports');

// WPML
function language_selector_flags(){
    $languages = icl_get_languages('skip_missing=0&orderby=code');
    if(!empty($languages)){
        foreach($languages as $l){
            if(!$l['active']) echo '<a href="'.$l['url'].'">';
            echo '<img src="'.$l['country_flag_url'].'" height="18" alt="'.$l['language_code'].'" width="20" />';
            if(!$l['active']) echo '</a>';
        }
    }
}

#------------------------------------------------------------#
###################### WooCommerce v5.1 ######################
#------------------------------------------------------------#

add_action( 'after_setup_theme', 'woocommerce_support' );
function woocommerce_support() {
    add_theme_support( 'woocommerce' );
}

require_once (get_template_directory() . '/woocommerce/functions-woocomerce.php');


#------------------------------------------------------------#
######### Gallery Shortcode development v6.0 ######################
#------------------------------------------------------------#

//Adding the custom fields to the WP Native Gallery Setting
//http://wordpress.stackexchange.com/questions/182821/add-custom-fields-to-wp-native-gallery-settings
//http://wordpress.stackexchange.com/questions/212708/allowing-for-multiple-template-views-on-the-gallery-settings-page-when-using-the
add_action('print_media_templates', function(){
?>
<script type="text/html" id="tmpl-custom-gallery-setting">
    <h3 style="z-index: -1;">___________________________________________________________________________________________</h3>
    <h3>Custom Gallery Settings</h3>
	<h5>In custom gallery types (Colorbox,FacyBox,PrettyPhoto,Slideviewer,<br/>Galleria,Orbit), Above default gallery setting fields <br/>"Columns,Link To,Size" don't support. It is getting overridden by below Custom Gallery options.</h5>
	
    <label class="setting">
      <span><?php _e('Gallery Type', 'kslang'); ?></span>
      <select data-setting="type">
		<option value="default"> Default WP Gallery </option>
		<option value="colorbox"> ColorBox </option>
		<option value="fancybox"> FancyBox </option>
		<option value="prettyphoto"> PrettyPhoto </option>
		<option value="slideviewer"> Slideviewer </option>
        <option value="galleria"> Galleria </option>
        <option value="orbit"> Orbit </option>
      </select>
    </label>

    <label class="setting">
        <span><?php _e('Gallery POST ID', 'kslang'); ?></span>
        <input type="text" value="" data-setting="gallery_id" style="float:left;">
    </label>
    
    <label class="setting">
      <span><?php _e('Gallery Layout', 'kslang'); ?></span>
      <select data-setting="layout">
		<option value="2"> 2 Columns </option>
		<option value="3"> 3 Columns </option>
		<option value="4"> 4 Columns </option>
        <option value="grid"> Grid </option>
      </select>
    </label>

    <label class="setting">
        <span><?php _e('Gallery Description', 'kslang'); ?></span>
        <textarea value="" data-setting="description" style="float:left;"></textarea>
    </label>
    
     <label class="setting">
      <span><?php _e('Gallery Description Placement', 'kslang'); ?></span>
      <select data-setting="placement">
		<option value="below"> Below </option>
		<option value="above"> Above </option>
      </select>
    </label>
    
</script>

<script>
   jQuery(document).ready(function () {

		// add your shortcode attribute and its default value to the
		// gallery settings list; $.extend should work as well...
		_.extend(wp.media.gallery.defaults, {
			layout: '2',
			type: 'default',
			placement: 'below',
			crop: 'center'
		});

		// join default gallery settings template with yours -- store in list
		if (!wp.media.gallery.templates) wp.media.gallery.templates = ['gallery-settings'];
		wp.media.gallery.templates.push('custom-gallery-setting');

		// loop through list -- allowing for other templates/settings
		wp.media.view.Settings.Gallery = wp.media.view.Settings.Gallery.extend({
			template: function (view) {
				var output = '';
				for (var i in wp.media.gallery.templates) {
					output += wp.media.template(wp.media.gallery.templates[i])(view);
				}
				return output;
			}
		});

	});
	
/*
    jQuery(document).ready(function()
    {
            
        _.extend(wp.media.gallery.defaults, {
			layout: '2',
			type: 'colorbox',
			crop: 'center'
        });

        wp.media.view.Settings.Gallery = wp.media.view.Settings.Gallery.extend({
        template: function(view){
          return wp.media.template('gallery-settings')(view)
               + wp.media.template('custom-gallery-setting')(view);
        },


        // this is function copies from WP core /wp-includes/js/media-views.js?ver=4.6.1
        update: function( key ) {
          var value = this.model.get( key ),
            $setting = this.$('[data-setting="' + key + '"]'),
            $buttons, $value;

          // Bail if we didn't find a matching setting.
          if ( ! $setting.length ) {
            return;
          }

          // Attempt to determine how the setting is rendered and update
          // the selected value.

          // Handle dropdowns.
          if ( $setting.is('select') ) {
            $value = $setting.find('[value="' + value + '"]');

            if ( $value.length ) {
              $setting.find('option').prop( 'selected', false );
              $value.prop( 'selected', true );
            } else {
              // If we can't find the desired value, record what *is* selected.
              this.model.set( key, $setting.find(':selected').val() );
            }

          // Handle button groups.
          } else if ( $setting.hasClass('button-group') ) {
            $buttons = $setting.find('button').removeClass('active');
            $buttons.filter( '[value="' + value + '"]' ).addClass('active');

          // Handle text inputs and textareas.
          } else if ( $setting.is('input[type="text"], textarea') ) {
            if ( ! $setting.is(':focus') ) {
              $setting.val( value );
            }
          // Handle checkboxes.
          } else if ( $setting.is('input[type="checkbox"]') ) {
            $setting.prop( 'checked', !! value && 'false' !== value );
          }
          // HERE the only modification I made
          else {
            $setting.val( value ); // treat any other input type same as text inputs
          }
          // end of that modification
        },
        });
    });
*/
</script>
<?php

});


############ Overriding the default gallery :: Custom filter function to modify default gallery shortcode output ############
function gallery_shortcode_modify( $output, $attr ) {
	
	global $data;
	
		$modifyGallery = false;		
	if ( isset( $attr['type'] ) && $attr['type'] != 'default'  ) { //Check if it is not a default gallery
		$modifyGallery = true;
	} elseif(is_page_template('template-colorbox.php')){ // EDIT this slug
		$modifyGallery = true;
	}  elseif(is_page_template('template-fancybox.php')){ // EDIT this slug
		$modifyGallery = true;
	}  elseif(is_page_template('template-prettyphoto.php')){ // EDIT this slug
		$modifyGallery = true;
	}  elseif(is_page_template('template-galleria.php')){ // EDIT this slug
		$modifyGallery = true;	
	}  elseif(is_page_template('template-slideviewer.php')){ // EDIT this slug
		$modifyGallery = true;
	}
	  
   if($modifyGallery == true) {
			
	// Initialize
	global $post, $wp_locale;
 
	// Gallery instance counter
	static $instance = 0;
	$instance++;
 
	// Validate the author's orderby attribute
	if ( isset( $attr['orderby'] ) ) {
		$attr['orderby'] = sanitize_sql_orderby( $attr['orderby'] );
		if ( ! $attr['orderby'] ) unset( $attr['orderby'] );
	}
	
		
	// Get attributes from shortcode
	extract( shortcode_atts( array(
		'order'      => 'ASC',
		'orderby'    => 'menu_order ID',
		'id'         => get_the_ID(),
		'mime_type'   => 'image',
		'link'        => '',
		'itemtag'    => 'dl',
		'icontag'    => 'dt',
		'captiontag' => 'dd',
		'columns'    => 3,
		'size'       => 'full',
		'ids'         => '',
		'include'    => '',
		'exclude'    => '',
		'numberposts' => -1,
		'offset'      => '',
		
		'gallery_id' => false,
        'type'	  => false,
		'layout'  => false,
		'description' => false,
		'placement'	=> false,
		'crop' => "center"
	), $attr ) );
	
	
	// variable setup	
	$post_id = ($id) ? $id  : '';
	$gallery_id = ($gallery_id) ? $gallery_id  : '';
	$gallery_type = ($type) ? $type  : 'prettyphoto';
	$layout = ($layout) ? $layout  : 2;
	$description = ($description) ? $description  : '';
	$placement = ($placement) ? $placement  : 'above';
	
	
	//Layout of the Gallery
	if($layout == "grid")
		$no_of_page_columns = "grid";
	elseif($layout == "2")
		$no_of_page_columns = "2columns";
	elseif($layout == "3")
		$no_of_page_columns = "3columns";
	elseif($layout == "4")
		$no_of_page_columns = "4columns";


	// Add Gallery type JS and CSS
	global $tpl_body_id;
	if($tpl_body_id != "blog_overview") ##fix the blog overview page error.
		$tpl_body_id = $gallery_type;
	
	
 
	// Initialize
	$id = intval( $id );
	$attachments = array();
	if ( $order == 'RAND' ) $orderby = 'none';
	
	if ( ! empty( $gallery_id ) ) { //If Gallery Id has been set then it will ignore all indiviual ids
		
		// Setup attachments array
		$attachments = get_children( array( 'post_parent' => $gallery_id, 'post_status' => 'inherit', 'post_type' => 'attachment', 'post_mime_type' => 'image', 'order' => $order, 'orderby' => $orderby ) );
		
	} elseif ( ! empty( $include ) ) {
 
		// Include attribute is present
		$include = preg_replace( '/[^0-9,]+/', '', $include );
		$_attachments = get_posts( array( 'include' => $include, 'post_status' => 'inherit', 'post_type' => 'attachment', 'post_mime_type' => 'image', 'order' => $order, 'orderby' => $orderby ) );
 
		// Setup attachments array
		foreach ( $_attachments as $key => $val ) {
			$attachments[ $val->ID ] = $_attachments[ $key ];
		}
 
	} else if ( ! empty( $exclude ) ) {
 
		// Exclude attribute is present 
		$exclude = preg_replace( '/[^0-9,]+/', '', $exclude );
 
		// Setup attachments array
		$attachments = get_children( array( 'post_parent' => $id, 'exclude' => $exclude, 'post_status' => 'inherit', 'post_type' => 'attachment', 'post_mime_type' => 'image', 'order' => $order, 'orderby' => $orderby ) );
	} else {
		// Setup attachments array
		$attachments = get_children( array( 'post_parent' => $id, 'post_status' => 'inherit', 'post_type' => 'attachment', 'post_mime_type' => 'image', 'order' => $order, 'orderby' => $orderby ) );
	}
	
	//If attachment is empty then
	if ( empty( $attachments ) ) return '';
	
	/* Count the number of attachments returned. */
		$attachment_count = count( $attachments );
 
	// Filter gallery differently for feeds
	if ( is_feed() ) {
		$output = "\n";
		foreach ( $attachments as $att_id => $attachment ) $output .= wp_get_attachment_link( $att_id, $size, true ) . "\n";
		return $output;
	}
 
	// Filter tags and attributes
	$itemtag = tag_escape( $itemtag );
	$captiontag = tag_escape( $captiontag );
	$columns = intval( $columns );
	$itemwidth = $columns > 0 ? floor( 100 / $columns ) : 100;
	$float = is_rtl() ? 'right' : 'left';
	$selector = "gallery-{$instance}";
 
	
	// Apply Gallery Type
	if($gallery_type=="colorbox")
		$relative_gal = 'rel="gallery-'.$post_id.'"';
	elseif($gallery_type=="prettyphoto")
		$relative_gal = 'rel="prettyPhoto[gallery-'.$post_id.']"';
	elseif($gallery_type=="fancybox")
		$relative_gal = 'rel="gallery-'.$post_id.'"';


		//<!-- Gallery start here -->
		##### Enable/Disabled Gallery Title #####
			$showTitle =  false;
		if($gallery_type == "colorbox" && $data["wm_gallery_titles_colorbox"] == "Enable Colorbox Titles")
			$showTitle =  true;	
		elseif($gallery_type == "fancybox" && $data["wm_gallery_titles_fancybox"] == "Enable Fancybox Titles")
			$showTitle =  true;	
		elseif($gallery_type == "prettyphoto" && $data["wm_gallery_titles_prettyphoto"] == "Enable PrettyPhoto Titles")
			$showTitle =  true;	
		elseif($gallery_type == "galleria" && $data["wm_gallery_titles_galleria"] == "Enable Galleria Titles")
			$showTitle =  true;	
		##### END Enable/Disabled Gallery Title #####

		#### getting the page Gallery attachments images ####
		ob_start();
		  
		if($description && $placement=="above")
			echo '<p>'.$description.'</p>';

		$url_post_img = "";		
		if($gallery_type == "colorbox" || $gallery_type == "prettyphoto" || $gallery_type == "fancybox") :
		?>

		<div class="row gallery-space pV0H10">
			<?php 
				if ($attachments) { 
					foreach ($attachments as $attachment) { 
						
						########### FIXING # OF COLUMN AND IMAGE URL ###########
						if($no_of_page_columns=="2columns"){
							$url_post_img = wm_image_resize('400','250', wp_get_attachment_url($attachment->ID),$str_crop);
							$div_layout = "six columns mobile-three";
						}
						elseif($no_of_page_columns=="3columns"){
							$url_post_img = wm_image_resize('400','250', wp_get_attachment_url($attachment->ID),$str_crop);
							$div_layout = "four columns mobile-four";
						}
						elseif($no_of_page_columns=="4columns"){
							$url_post_img = wm_image_resize('400','250', wp_get_attachment_url($attachment->ID),$str_crop);
							$div_layout = "three columns mobile-one";
						}
						elseif($no_of_page_columns=="grid"){
							$url_post_img = wm_image_resize('500','500', wp_get_attachment_url($attachment->ID),$str_crop);
							$div_layout = "six_col columns grid_columns mobile-one";
						}

						########### POST Title ###########
						if($gallery_type == "prettyphoto" && !empty($attachment->post_content))
							$post_title = "<p>".strip_tags(wptexturize($attachment->post_content))."</p>";
						elseif(!empty($attachment->post_content))
							$post_title = wptexturize($attachment->post_title)."<p>".strip_tags(wptexturize($attachment->post_content))."</p>";
						else
							$post_title = wptexturize($attachment->post_title);

						########### POST ALT ########
						if(get_post_meta($attachment->ID, '_wp_attachment_image_alt', true) == "")
							$post_alt = wptexturize($attachment->post_title);
						else
							$post_alt = wptexturize(get_post_meta($attachment->ID, '_wp_attachment_image_alt', true));
						
						########### Gallery Column CLASS ###########
						if($gallery_type=="colorbox"){

						  $class_gal = 'gallery_'.$layout;
						  
						  if($layout!='grid') 
							$class_gal .= "col";
						}
						elseif($gallery_type=="prettyphoto"){

						  $class_gal = 'gallery_'.$layout;
						  
						  if($layout!='grid') 
							$class_gal .= "col";

							if($layout=='grid') 
								$relative_gal = 'rel="prettyPhoto[gallery'.$layout.']"';
							else
								$relative_gal = 'rel="prettyPhoto[gallery'.$layout.'col]"';
						}
						elseif($gallery_type=="fancybox"){
							
						  $class_gal = 'fancybox gallery_'.$layout;
						  
						  if($layout!='grid') 
							$class_gal .= "col";

							if($layout=='grid') 
								$relative_gal = 'data-fancybox-group="gallery_'.$layout.'"';
							else
								$relative_gal = 'data-fancybox-group="gallery_'.$layout.'col"';
						}
				?>
					<div class="<?php echo $div_layout;?> space-bottom mobile-fullwidth">
						<div class="row">
							<div class="twelve columns pV0H5 gallery_<?php echo $gallery_type;?>">
								<a class="<?php echo $class_gal?> image" <?php echo $relative_gal;?>  href="<?php echo wp_get_attachment_url($attachment->ID);?>" title="<?php  if($showTitle == true) echo $post_title; ?>">
							<?php
							if($data["wm_lazyloader_option"] == "Enable Lazyloader") :
							?>
								<img  class="lazy" data-original="<?php echo $url_post_img;?>" src="<?php echo get_template_directory_uri();?>/images/loading.gif" alt="<?php  if($showTitle == true) echo $post_alt;  ?>" title="<?php  if($showTitle == true) echo $attachment->post_title;  ?>"/>
							<?php
							else :
							 ?>
								<img src="<?php echo $url_post_img;?>" alt="<?php  if($showTitle == true) echo $post_alt;  ?>" title="<?php  if($showTitle == true) echo $attachment->post_title;  ?>"/>
							<?php
							endif;
							?>
								</a>
							</div>
						</div>
					</div>                 
						
			<?php
				   }
				}
			?>	

		</div>            

		<?php elseif ($gallery_type == "galleria"): ?>
		<!-- Galleria - place you images here -->
			<div class="row">
			   <div id="galleria">	
				<?php 
					//getting the page Gallery attachments images
					if ($attachments) { 
						foreach ($attachments as $attachment) { 				
							
							$url_post_img = wm_image_resize('680','450', wp_get_attachment_url($attachment->ID),$str_crop);
							$url_post_img_thumb = wm_image_resize('100','50', wp_get_attachment_url($attachment->ID),$str_crop);
							
							
						if(!empty($attachment->post_content))
							$post_title = $attachment->post_title."<p>".strip_tags($attachment->post_content)."</p>";
						elseif(get_post_meta($attachment->ID, '_wp_attachment_image_alt', true) == "")
							$post_title = $attachment->post_title;
						else
							$post_title = get_post_meta($attachment->ID, '_wp_attachment_image_alt', true);
							
						if(get_post_meta($attachment->ID, '_wp_attachment_image_alt', true) == "")
							$post_alt = $attachment->post_title;
						else
							$post_alt = get_post_meta($attachment->ID, '_wp_attachment_image_alt', true);

						if($showTitle == true) {	
							echo '<a href="'.$url_post_img.'">';
								echo '<img title="'.$post_title.'" data-title="'.$post_title.'"  src="'.$url_post_img_thumb.'"  data-big="'.wp_get_attachment_url($attachment->ID).'"
									   data-description=""  />';
							echo '</a>';
						}
						else{
							echo '<a href="'.$url_post_img.'">';
								echo '<img title="'.$post_title.'" data-title="'.$post_title.'"  src="'.$url_post_img_thumb.'"  data-big="'.wp_get_attachment_url($attachment->ID).'"
									   data-description=""  />';
							echo '</a>';
						}
				
					   }
					}
				?>	
			 </div>	
		  </div>	
		<!-- Galleria ends here -->

		<?php elseif ($gallery_type == "slideviewer"): ?>

		<!-- slideviewer - place you images here -->
			 <div class="row">
			 <!-- slideviewer - place you images here -->
			   <div id="gallerySlideviewer">	
				<ul class="rslides" id="slider">
					<?php 
						if ($attachments) { 
							foreach ($attachments as $attachment) { 										
								$url_post_img = wm_image_resize('680','450', wp_get_attachment_url($attachment->ID),$str_crop);
								$post_title = $attachment->post_title;
										
								if(get_post_meta($attachment->ID, '_wp_attachment_image_alt', true) == "")
									$post_alt = $attachment->post_title;
								else
									$post_alt = get_post_meta($attachment->ID, '_wp_attachment_image_alt', true);
									
						
								if($showTitle == true) {
									echo '<li><img alt="'.$post_alt.'" title="'.$post_title.'" src="'.$url_post_img.'" /></li>'; 
								}else{
									echo '<li><img alt="'.$post_alt.'" title="" src="'.$url_post_img.'" /></li>'; 
								}
					
						   }
						}
					?>	
					</ul>
				</div>
				<!-- slideviewer ends here -->
			</div>
		<!-- slideviewer ends here -->

		<!--Orbit Slider Start-->
		<?php elseif ($gallery_type == "orbit"): ?>
		  <div id="featured">
			  <?php
			  if ($attachments) { 
				 foreach ($attachments as $attachment) { 
					 
					$url_post_img = wm_image_resize('680','450', wp_get_attachment_url($attachment->ID),$str_crop);
					$post_title = $attachment->post_title;
							
					if(get_post_meta($attachment->ID, '_wp_attachment_image_alt', true) == "")
						$post_alt = $attachment->post_title;
					else
						$post_alt = get_post_meta($attachment->ID, '_wp_attachment_image_alt', true);
			  ?>
			  <img  src="<?php echo $url_post_img;?>"  title="<?php if($showTitle == true) echo $post_title;?>" alt="<?php if($showTitle == true) echo $post_alt;?>"/>
			  <?php
			   }
			}
			?>
			</div>
		<!--Ends Orbit Slider Start-->

		<?php
		endif;
		//<!-- Gallery ends here -->

		if($description && $placement=="below")
			echo '<p>'.$description.'</p>';

		$output = ob_get_contents();
		ob_end_clean();
		// End gallery output
		// Iterate through the attachments in this gallery instance
		//http://robido.com/wordpress/wordpress-gallery-filter-to-modify-the-html-output-of-the-default-gallery-shortcode-and-style/
			
	}

 
	return $output;
 
}
// Apply filter to default gallery shortcode
add_filter( 'post_gallery', 'gallery_shortcode_modify', 10, 2 );




####### Check if Gallery Shortcode finder in content #########
function shortcodes_exist( $content = '', $match_all = false, $shortcodes = array('img_gallery') ) {

	$found_shortcodes = array();

	foreach( $shortcodes as $shortcode ) {
		if ( shortcode_exists( $shortcode ) ) {
			$found_shortcodes[] = $shortcode;
		} else {
			if ( $match_all ) {
				return false;
			}
		}
	}
	
	
	if ( count( $found_shortcodes ) === 0 ) {
		return false;
	} else {

		if($content != '') {
			preg_match_all("/\[(gallery.*?)\]/", $content, $matches);
			return $matches;
		} else {
			return $found_shortcodes;
		}
	
	}
}


//https://wordpress.stackexchange.com/questions/190474/sticky-posts-for-each-category-archive-php
function get_term_sticky_posts()
{
    // First check if we are on a category page, if not, return false
    if ( !is_category() )
        return false;

    // Secondly, check if we have stickies, return false on failure
    $stickies = get_option( 'sticky_posts' );

    if ( !$stickies )
        return false;

    // OK, we have stickies and we are on a category page, continue to execute. Get current object (category) ID
    $current_object = get_queried_object_id();

    // Create the query to get category specific stickies, just get post ID's though
    $args = [
        'nopaging' => true,
        'post__in' => $stickies,
        'cat' => $current_object,
        'ignore_sticky_posts' => 1,
        'fields' => 'ids'
    ];
    $q = get_posts( $args );

    return $q;
}

add_action( 'pre_get_posts', function ( $q )
{
    if (    !is_admin() // IMPORTANT, make sure to target front end only
         && $q->is_main_query() // IMPORTANT, make sure we only target the main query
         && $q->is_category() // Only target category archives
    ) {
        // Check if our function to get term related stickies exists to avoid fatal errors
        if ( function_exists( 'get_term_sticky_posts' ) ) {
            // check if we have stickies
            $stickies = get_term_sticky_posts();
            if ( $stickies ) {
                // Remove stickies from the main query to avoid duplicates
                $q->set( 'post__not_in', $stickies );

                // Check that we add stickies on the first page only, remove this check if you need stickies on all paged pages
                if ( !$q->is_paged() ) {

                    // Add stickies via the the_posts filter
                    add_filter( 'the_posts', function ( $posts ) use ( $stickies )
                    {   
                        $term_stickies = get_posts( ['post__in' => $stickies, 'nopaging' => true] );

                        $posts = array_merge( $term_stickies, $posts );

                        return $posts;
                    }, 10, 1 );
                }
            }
        }
    }
});



########## WooCommerce Photo Gallery 
function df_woocommerce_single_product_image_html($html) {
    $html = str_replace('data-rel="prettyPhoto', 'rel="lightbox', $html);
    return $html;
}
add_filter('woocommerce_single_product_image_html', 'df_woocommerce_single_product_image_html', 99, 1); // single image
add_filter('woocommerce_single_product_image_thumbnail_html', 'df_woocommerce_single_product_image_html', 99, 1); // thumbnails


############# How to remove Customize from admin menu bar ###################
function remove_customize() {
    $customize_url_arr = array();
    $customize_url_arr[] = 'customize.php'; // 3.x
    $customize_url = add_query_arg( 'return', urlencode( wp_unslash( $_SERVER['REQUEST_URI'] ) ), 'customize.php' );
    $customize_url_arr[] = $customize_url; // 4.0 & 4.1
    if ( current_theme_supports( 'custom-header' ) && current_user_can( 'customize') ) {
        $customize_url_arr[] = add_query_arg( 'autofocus[control]', 'header_image', $customize_url ); // 4.1
        $customize_url_arr[] = 'custom-header'; // 4.0
    }
    if ( current_theme_supports( 'custom-background' ) && current_user_can( 'customize') ) {
        $customize_url_arr[] = add_query_arg( 'autofocus[control]', 'background_image', $customize_url ); // 4.1
        $customize_url_arr[] = 'custom-background'; // 4.0
    }
    foreach ( $customize_url_arr as $customize_url ) {
        remove_submenu_page( 'themes.php', $customize_url );
    }
}
add_action( 'admin_menu', 'remove_customize', 999 );

add_filter('wp_generate_attachment_metadata', 'retina_support_attachment_meta', 10, 2);

/**
 * Retina images
 *
 * This function is attached to the 'wp_generate_attachment_metadata' filter hook.
 */
function retina_support_attachment_meta($metadata, $attachment_id) {
    foreach ($metadata as $key => $value) {

        // Get value of base images width
        if ($key == 'width') {
            $width = $value;
        }
        // Get value of base images height
        if ($key == 'height') {
            $height = $value;
        }
        if (is_array($value)) {
            foreach ($value as $image => $attr) {
                if (is_array($attr))
                    //Return all sizes of 2x images
                    retina_support_create_images(get_attached_file($attachment_id), $attr['width'], $attr['height'], true);
            }
        }
    }
    //Return base size of 2x images
    retina_support_base_img(get_attached_file($attachment_id), $width, $height, true);

    return $metadata;
}

/**
 * Create retina-ready images for base image
 *
 * Referenced via retina_support_attachment_meta().
 */
function retina_support_base_img($base_file_path, $width, $height, $crop = true) {

    $resized_file = wp_get_image_editor($base_file_path);

    if (!is_wp_error($resized_file)) {
        $dir = pathinfo($base_file_path, PATHINFO_DIRNAME);
        $ext = pathinfo($base_file_path, PATHINFO_EXTENSION);
        $name = wp_basename($base_file_path, ".$ext");
        $suffix = '@2x';
        $filename = trailingslashit($dir) . "{$name}{$suffix}.{$ext}";
        $resized_file->resize($width * 2, $height * 2, $crop);
        $resized_file->save($filename);
        $info = $resized_file->get_size();
        return array(
            'file' => wp_basename($filename),
            'width' => $info['width'],
            'height' => $info['height']
        );
    }
}

/**
 * Create retina-ready images for all size of images
 *
 * Referenced via retina_support_attachment_meta().
 */
function retina_support_create_images($file, $width, $height, $crop = false) {
    if ($width || $height) {
        $resized_file = wp_get_image_editor($file);
        if (!is_wp_error($resized_file)) {
            $filename = $resized_file->generate_filename($width . 'x' . $height . '@2x');
            $resized_file->resize($width * 2, $height * 2, $crop);
            $resized_file->save($filename);
            $info = $resized_file->get_size();
            return array(
                'file' => wp_basename($filename),
                'width' => $info['width'],
                'height' => $info['height']
            );
        }
    }
    return false;
}

add_filter('delete_attachment', 'delete_retina_support_images');

/**
 * Delete retina-ready images
 *
 * This function is attached to the 'delete_attachment' filter hook.
 */
function delete_retina_support_images($attachment_id) {
    $meta = wp_get_attachment_metadata($attachment_id);
    $upload_dir = wp_upload_dir();
    $path = pathinfo($meta['file']);
    foreach ($meta as $key => $value) {
        if ('sizes' === $key) {
            // Remove all retina images.
            foreach ($value as $sizes => $size) {
                $original_filename = $upload_dir['basedir'] . '/' . $path['dirname'] . '/' . $size['file'];
                $retina_filename = substr_replace($original_filename, '@2x.', strrpos($original_filename, '.'), strlen('.'));
                if (file_exists($retina_filename)) {
                    unlink($retina_filename);
                }
            }
        }
    }

    // Remove base name retina image.
    $original_base_filename = $upload_dir['basedir'] . '/' . $path['dirname'] . '/' . $path['basename'];
    $retina_base_filename = substr_replace($original_base_filename, '@2x.', strrpos($original_base_filename, '.'), strlen('.'));
    if (file_exists($retina_base_filename)) {
        unlink($retina_base_filename);
    }
}
